.. _ligo_defaults:
LIGO Analysis Defaults
======================

In this cookbook we'll provide the default settings which are used for the various analyses in LIGO publications.
These can either be used directly in your own analysis, or you can adapt the YAML files which provide them to suit your own requirements.

.. literalinclude:: defaults/bayeswave.yaml
   :language: yaml
   :linenos:
